sqlobject.tests.test_SQLRelatedJoin module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_SQLRelatedJoin module

class `sqlobject.tests.test_SQLRelatedJoin.` `Fighter`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addTourtment`(obj)
  `j` = fighter
  property `name`
  `q` = fighter
  `removeTourtment`(obj)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'fighter_id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_SQLRelatedJoin.Fighter`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'fighter'
  property `tourtments`

class `sqlobject.tests.test_SQLRelatedJoin.` `Tourtment`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addFighter`(obj)
  property `fightersAsList`
  property `fightersAsSResult`
  `j` = competition
  property `name`
  `q` = competition
  `removeFighter`(obj)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>, <sqlobject.joins.SQLRelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>, <sqlobject.joins.SOSQLRelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_SQLRelatedJoin.Tourtment`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'competition'

`sqlobject.tests.test_SQLRelatedJoin.` `createAllTables`()

`sqlobject.tests.test_SQLRelatedJoin.` `test_1`()

`sqlobject.tests.test_SQLRelatedJoin.` `test_related_join_transaction`()